{
***********************************************************
*     dlfdll_import.pas - an import unit for the dlfunit DLL
*     Author: Prof A Olowofoyeku (The African Chief)
*     Licence : FREEWARE
*     Last amended: 3 August 2004
**************************************************************
}
UNIT dlfdll_import;

INTERFACE

{$I-,X+}
CONST
fNamelen = 30;
MaxFileNums = 2048;

TYPE
// data TYPE FOR FILE names IN DLF
FNameType = ARRAY [0 .. FNamelen - 1] OF char;

// data TYPE FOR directories IN DLF
DirType   = ARRAY [0 .. 14] OF char;

// our unsigned integer TYPE
Dlf_Word  = Cardinal;

// the DLF archive header
pDLF_HEADER = ^DLF_HEADER;
DLF_HEADER = PACKED RECORD
     FileCount,                // 4  = number OF files IN archive
     CompressionType,          // 8  = compression TYPE ?
     StartofFileData,          // 12 = offset FOR data
     HeaderEnd : Dlf_Word;     // 16 = END OF header ( zeroes )
END;

// FOR DLF archive FILE records
pDLF_FileRec = ^DLF_FileRec;
DLF_FileRec = PACKED RECORD
   FName  : FNameType;    // 30
   FSize  : DLF_Word;     // 34
   FDir   : DirType;      // 49
   FileID : DLF_Word;     // 53
END;

// TO store FILE offsets
FileOffsets = RECORD
  Start, Stop : DLF_Word;
END;

// full RECORD FOR files
pDLF_FileRecFull = ^DLF_FileRecFull;
DLF_FileRecFull = PACKED RECORD
   FName  : FNameType;    // 30
   FSize  : DLF_Word;     // 34
   FDir   : DirType;      // 49
   FileID : DLF_Word;     // 53
   Start,                 // 57
   Stop   : DLF_Word;     // 61
END;

// callback TYPE FOR listing DLF
TDLFListFunc = FUNCTION ( Head : pDLF_Header; FRrec : pDLF_FileRecFull )
: Integer STDCALL;

// callback TYPE FOR other processing OF DLF
TDLFArchiveFunc = FUNCTION ( FileName : pChar; Head : pDLF_HEADER; ID, Size, Copied : Longint )
: Integer STDCALL;

// ARRAY OF about 100kb size TO
// hold the FILE records ( up TO 2048 OF them )
RecArrayType = ARRAY [1..MaxFileNums] OF DLF_FileRec;

// ARRAY TO store FILE offsets
OffSetArrayType = ARRAY [1..MaxFileNums] OF FileOffSets;


// * * * * * * * * * * *  exported routines * * * * * * * * * * * * * * * * * * * //
// All these functions return a positive number IF successful,
// otherwise they return a negative error code

// create archive
FUNCTION CreateDLF ( ArchiveName, ArchiveFSpecs : pChar;
CallBack : TDLFArchiveFunc ) : Integer; STDCALL;

// extract the contents OF the archive
FUNCTION ExtractDLF ( FileName, aTargetDir : pChar;
CallBack : TDLFArchiveFunc ) : Integer; STDCALL;

// list the contents OF the archive
FUNCTION ListDLF ( FileName : pChar; CallBackFunc : TDLFListFunc ) : Integer; STDCALL;

// obtain header information from DLF
FUNCTION ParseDLFArchive ( FileName : pChar;
                      VAR Head : DLF_Header;
                      VAR FRec : RecArrayType;
                      VAR Offsets : OffSetArrayType ) : Integer;STDCALL;

FUNCTION DLFTitle : pChar;STDCALL;
FUNCTION DLFVersion : pChar;STDCALL;
FUNCTION DLFAuthor : pChar;STDCALL;
FUNCTION DLLVersion : Integer; STDCALL;


IMPLEMENTATION

CONST dlfdll = 'dlfunit.dll';

FUNCTION DLLVersion;      external dlfdll name 'DLLVersion';
FUNCTION CreateDLF;       external dlfdll name 'CreateDLF';
FUNCTION ExtractDLF;      external dlfdll name 'ExtractDLF';
FUNCTION ListDLF;         external dlfdll name 'ListDLF';
FUNCTION ParseDLFArchive; external dlfdll name 'ParseDLFArchive';
FUNCTION DLFTitle;        external dlfdll name 'DLFTitle';
FUNCTION DLFVersion;      external dlfdll name 'DLFVersion';
FUNCTION DLFAuthor;       external dlfdll name 'DLFAuthor';

END.

